==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/zh_TW.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} 釋出了，可以更新",
    "Could not start updater, please try the manual update" : "無法啟動更新程式，請嘗試手動更新",
    "Open updater" : "打開更新程式",
    "Download now" : "現在下載",
    "Your version is up to date." : "您的版本是最新版",
    "The update check is not yet finished. Please refresh the page." : "更新檢查未完成，請刷新這個頁面",
    "A non-default update server is in use to be checked for updates:" : "沒有預設的更新伺服器以至於無法檢查更新：",
    "Update channel:" : "更新通道:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "您可以隨時更新至較新的版本 / 實驗通道，但您不能降版至更穩定的通道。",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "請注意，新版本釋出後，需要過一段時間才會在此顯示通知。隨著時間推進，我們為用戶推出了新的版本，有時候會在發現問題時跳過前一個版本更新。",
    "Notify members of the following groups about available updates:" : "有可用更新時通知這些群組：",
    "Only notification for app updates are available." : "僅提供應用程式更新的通知",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選擇的更新管道會導致伺服器專門的通知過期",
    "The selected update channel does not support updates of the server." : "所選的更新頻道不提供伺服器軟體的更新",
    "Update notifications" : "更新通知",
    "Channel updated" : "頻道已更新",
    "The update server could not be reached since %d days to check for new updates." : "更新伺服器在%d天前已經無法連線檢查更新",
    "Please check the Nextcloud and server log files for errors." : "請確認伺服器log檔以查看錯誤。",
    "Update to %1$s is available." : "更新版 %1$s 已經釋出",
    "Update for %1$s to version %2$s is available." : "%1$s 到 %2$s 的更新已經釋出",
    "Update for {app} to version %s is available." : "{app} 已有 %s 版本的更新",
    "A new version is available: %s" : "新版本可用：%s",
    "Checked on %s" : "於 %s 檢查過"
},
"nplurals=1; plural=0;");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/zh_TW.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} 釋出了，可以更新",
    "Channel updated" : "頻道已更新",
    "Update notifications" : "更新通知",
    "The update server could not be reached since %d days to check for new updates." : "更新伺服器在%d天前已經無法連線檢查更新",
    "Please check the Nextcloud and server log files for errors." : "請確認伺服器log檔以查看錯誤。",
    "Update to %1$s is available." : "更新版 %1$s 已經釋出",
    "Update for %1$s to version %2$s is available." : "%1$s 到 %2$s 的更新已經釋出",
    "Update for {app} to version %s is available." : "{app} 已有 %s 版本的更新",
    "Update notification" : "更新通知",
    "View in store" : "在商店中檢視",
    "Open updater" : "打開更新程式",
    "Download now" : "現在下載",
    "The update check is not yet finished. Please refresh the page." : "更新檢查未完成，請刷新這個頁面",
    "Your version is up to date." : "您的版本是最新版",
    "A non-default update server is in use to be checked for updates:" : "沒有預設的更新伺服器以至於無法檢查更新：",
    "Update channel:" : "更新通道:",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "請注意，新版本釋出後，需要過一段時間才會在此顯示通知。隨著時間推進，我們為用戶推出了新的版本，有時候會在發現問題時跳過前一個版本更新。",
    "Notify members of the following groups about available updates:" : "有可用更新時通知這些群組：",
    "Only notification for app updates are available." : "僅提供應用程式更新的通知",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選擇的更新管道會導致伺服器專門的通知過期",
    "The selected update channel does not support updates of the server." : "所選的更新頻道不提供伺服器軟體的更新",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "請確定您的 config.php 設定檔中並沒有將<samp>appstoreenabled</samp>的值設定為 false",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "無法連線至應用程式商店，或者應用程式商店回應無任何更新，請您手動搜尋更新，或者修復您伺服器的網際網路連線，讓它可以連線至應用程式商店。",
    "View changelog" : "檢視版本更新紀錄",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "您可以隨時更新至較新的版本 / 實驗通道，但您不能降版至更穩定的通道。"
},
"nplurals=1; plural=0;");
